@@ -20,5 +20,5 @@
 
 class VersionValues(object):
     NAME = "AceQL HTTP SDK"
-    VERSION = "v5.2"
-    DATE = "03-Dec-2021"
+    VERSION = "v5.4"
+    DATE = "15-Apr-2022"
